#
# spec file for package nfs4-acl-tools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nfs4-acl-tools
Version:        0.3.7
Release:        3.2
Summary:        Command line tools for managing ACLs over NFSv4
License:        BSD-3-Clause
Group:          System/Filesystems
URL:            http://linux-nfs.org/~bfields/nfs4-acl-tools/
Source0:        http://linux-nfs.org/~bfields/nfs4-acl-tools/nfs4-acl-tools-%{version}.tar.gz
# GitClone:     http://git.linux-nfs.org/?p=bfields/nfs4-acl-tools.git
Patch2:         nfs-acl-tools-xattr.patch
BuildRequires:  libtool

%description
Command line tools for viewing and setting ACLs (Access Control Lists)
when using NFSv4 to access a remote filesystem. The remote filesystem
must also support ACLs.

%prep
%autosetup -p1

%build
autoreconf -fi
export CFLAGS="$RPM_OPT_FLAGS -fPIE"
export LDFLAGS="-pie"
%configure
%make_build

%install
# Don't try to chown/chgrp as we build as non-root
export CHOWNPROG=: CHGRPPROG=:
%make_install

%files
%license COPYING
%doc README TODO VERSION
%{_bindir}/nfs4_editfacl
%{_bindir}/nfs4_getfacl
%{_bindir}/nfs4_setfacl
%{_mandir}/man1/*
%{_mandir}/man5/*

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Apr 26 2022 Neil Brown <nfbrown@suse.com>
- Disable CHOWN/CHGRP call in install_sh as we build code
  as non-root
* Thu May 20 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.3.7
  * Remove OWNER_AT, GROUP_AT, EVERYONE_AT flags, but it is still
    possible to set these bits using the "O", "G", and "E" in the
    flag field on the commandline.
  * Add new option -c/--omit-header to not display comment header.
  * Skip comment field while reading ACE(s). Fixes an issue where
    nfs4_setfacl failed to handle comments while reading ACE(s)
    from nfs4_getfacl output.
  * Improved readability: add empty line after each acl
  * nfs4_getfacl: return 1 for unknown option and won't use '-?' anymore
  * nfs4_setfacl: Add file name to error output.
* Thu Nov 28 2019 Neil Brown <nfbrown@suse.com>
- nfs4-acl-tools-0.3.5.tar.gz - new upstream release
- Refresh nfs-acl-tools-xattr.patch
- Delete allow-spaces-in-principal-names.patch - included upstream
  Includes fix for bug 967251 : setting inheritable ACLs with -R
  Includes other fixes including an fd leak, man page typos and
  proper handling of DENY ACEs.
  (bsc#96725, boo#1157915)
* Thu May 29 2014 crrodriguez@opensuse.org
- nfs-acl-tools-xattr.patch For over 10 years the *xattr*
  functions have been in glibc instead of libattr, use them instead.
* Mon Mar 24 2014 nfbrown@suse.com
- allow-spaces-in-principal-names.patch
  upstream patch to allow spaces in principal names.
  (bnc#772896)
* Sun Jun 16 2013 coolo@suse.com
- aclocal 1.13 doesn't have a --acdir option
* Wed Mar  6 2013 cfarrell@suse.com
- license update: BSD-3-Clause
  GPL matches are for e.g. Makefile. Consolidate to BSD (as per Fedora)
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Wed Aug 24 2011 dmueller@suse.de
- remove strip to generate debuginfo
- remove generic INSTALL file
* Wed Aug 17 2011 nfbrown@novell.com
- Initial check-in of nfs4-acl-tools: FATE:312654
